@@ -70,7 +70,6 @@ class EncoderDecoderLM:
                  use_auth_token: bool = False,
                  max_length_encoder: int = None,
                  max_length_decoder: int = None,
-                 device: str = None,
                  num_gpus: int = None,
                  torch_dtype=None,
                  device_map: str = None,
@@ -108,7 +107,7 @@ class EncoderDecoderLM:
             num_gpus = torch.cuda.device_count() if num_gpus is None else num_gpus
             if num_gpus > 0:
                 self.model = torch.nn.DataParallel(self.model) if num_gpus > 1 else self.model
-                self.model.to(device)
+                self.model.to('cuda')
         logging.info(f'\t * model is loaded on: {self.model.device}')
         self.model.eval()
 
@@ -150,7 +149,6 @@ class EncoderDecoderLM:
                 # shift the label sequence for causal inference
                 label = output_encode["input_ids"]
                 label[label == self.tokenizer.pad_token_id] = PAD_TOKEN_LABEL_ID
-                # label = torch.concat([label[:, 1:], torch.tensor([[PAD_TOKEN_LABEL_ID] * label.shape[0]]).T], dim=1)
                 model_inputs["labels"] = label.to(self.model.device)
 
                 # model run & loss conversion into likelihood
