@@ -31,7 +31,6 @@ class LM:
                  model: str = 'distilgpt2',
                  use_auth_token: bool = False,
                  max_length: int = None,
-                 device: str = None,
                  num_gpus: int = None,
                  torch_dtype=None,
                  device_map: str = None,
@@ -75,7 +74,7 @@ class LM:
             num_gpus = torch.cuda.device_count() if num_gpus is None else num_gpus
             if num_gpus > 0:
                 self.model = torch.nn.DataParallel(self.model) if num_gpus > 1 else self.model
-                self.model.to(device)
+                self.model.to('cuda')
         logging.info(f'\t * model is loaded on: {self.model.device}')
         self.model.eval()
 
